@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2019 Greenbone Networks GmbH
+# Copyright (C) 2019-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -407,13 +407,13 @@ class HelpFormattingParserTestCase(ParserTestCase):
             os.environ['COLUMNS'] = self.columns
 
     def _snapshot_specific_path(self, name):
-        return __here__ / '{}.{}.snap'.format(name, self.python_version)
+        return __here__ / f'{name}.{self.python_version}.snap'
 
     def _snapshot_generic_path(self, name):
-        return __here__ / '{}.snap'.format(name)
+        return __here__ / f'{name}.snap'
 
     def _snapshot_failed_path(self, name):
-        return __here__ / '{}.{}-failed.snap'.format(name, self.python_version)
+        return __here__ / f'{name}.{self.python_version}-failed.snap'
 
     def _snapshot_path(self, name):
         snapshot_specific_path = self._snapshot_specific_path(name)
@@ -429,7 +429,7 @@ class HelpFormattingParserTestCase(ParserTestCase):
         if not path.exists():
             path.write_text(output)
 
-        content = path.read_text()
+        content = path.read_text(encoding='utf-8')
 
         try:
             self.assertEqual(content, output, 'Snapshot differs from output')
